# cx-logger

That is really easy to use automatic logger. To start using it in app just
install it.

```bash
pip install cx-logger
```

When library had been installed, import it. All code snippets above would use
